import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Tab, Tabs } from '@antmjs/vantui';
import Page from '@/layouts/index';
import PowerList from '@/components/PowerList';
import Card from '@/components/IssueCard';
import { getTaIssueApply } from '@/services/taissueapply';
import { ROLE_MANAGER } from '@/utils/user';
import { useModel } from '@/store';
import { getIssueStatus } from '@/utils/biz';

export default (props) => {

  const router = Taro.useRouter();
  const { title, applyType = '' } = router.params;

  React.useMemo(() => {
    if (title) {
      Taro.setNavigationBarTitle({ title });
    } else {
      Taro.setNavigationBarTitle({ title: '申请列表' });
    }
  }, [title]);

  const { user } = useModel('user');

  const onClick = (item) => {
    if (!user) return ;

    if (user.dutyList.indexOf(ROLE_MANAGER) > -1) {
      if (item.verifyStatus) {
        Taro.navigateTo({
          url: `/pages/apply/detail/index?id=${item.applyId}&issueId=${item.issueId}&applyType=${item.applyType}`
        })
      } else {
        Taro.navigateTo({
          url: `/pages/apply/verify/index?id=${item.applyId}&issueId=${item.issueId}&applyType=${item.applyType}`
        })
      }
    } else {
      Taro.navigateTo({
        url: `/pages/apply/detail/index?id=${item.applyId}&issueId=${item.issueId}&applyType=${item.applyType}`
      })
    }
  }
  
  return (
    <Page>
      <Tabs sticky>
        <Tab title="监督员">
          <PowerList
            request={getTaIssueApply}
            params={{applyType, sourceType: 'inspector'}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} stText={title} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="市民">
          <PowerList
            request={getTaIssueApply}
            params={{applyType, sourceType: 'feedback'}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} stText={title} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
      </Tabs>
    </Page>
  )
}
