import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Tab, Tabs } from '@antmjs/vantui';
import Page from '@/layouts/index';
import PowerList from '@/components/PowerList';
import Card from '@/components/IssueCard';
import { getTaIssue } from '@/services/taissue';
import { ROLE_MANAGER } from '@/utils/user';
import { useModel } from '@/store';
import { getIssueStatus } from '@/utils/biz';

export default (props) => {

  const router = Taro.useRouter();
  const { title, bizStatus = '', mine = '' } = router.params;

  React.useMemo(() => {
    if (title) {
      Taro.setNavigationBarTitle({ title });
    } else {
      Taro.setNavigationBarTitle({ title: '问题列表' });
    }
  }, [title]);

  const { user } = useModel('user');

  const onClick = (item) => {

    let act = '';
    const status = getIssueStatus(item);

    // 如果是管理员
    if (user.dutyList.indexOf(ROLE_MANAGER) > -1) {
      // 如果是待交办
      if (status.value === 0) {
        act = 'assigned';
      }
    } else {
      
    }

    Taro.navigateTo({
      url: `/pages/issue/edit/index?id=${item.issueId}&act=${act}`
    })
  }
  
  return (
    <Page>
      <Tabs sticky>
        <Tab title="监督员">
          <PowerList
            request={getTaIssue}
            params={{bizStatus, mine, sourceType: 'inspector'}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
        <Tab title="市民">
          <PowerList
            request={getTaIssue}
            params={{bizStatus, mine, sourceType: 'feedback'}}
            renderItem={(item) => (
              <Card key={item.issueId} detail={item} onClick={() => onClick(item)} />
            )}
          />
        </Tab>
      </Tabs>
    </Page>
  )
}
